@@ -387,7 +387,7 @@ class AppForm(qt.QMainWindow):
     def convert_and_write(self, fname, format_, data, header):
         if format_ == '*.bin':
             out = open(fname, mode="wb")
-            out.write(data.tostring())
+            out.write(data.tobytes())
             out.close()
             return
         elif format_ == '*.marccd':
