@@ -67,6 +67,13 @@ MAGIC_NUMBERS = [
     (b"\x49\x49\x2a\x00", 'tif'),
     # d*TREK must come before edf
     (b"{\nHEA", 'dtrek'),
+    # EDF_ types 
+    (b"\r\n{\r\nEDF",'edf'),   # EDF3 (can be interpreted like EDF1 but refused by fit2d)
+    (b"\n{\r\nEDF",'edf'),     # EDF2 (can be interpreted like EDF1 but refused by fit2d)
+    (b"{\r\nEDF",'edf'),       # EDF1 (EDF >=V2.4 starting with EDF_, fit2d friendly, without starting newline)
+    (b"{\n",'edf'),            # EDF0 (EDF V1.xx "standard", without additional EDF_ structure information)
+    (b"\n{\n",'edf'),          # EDFU (EDF unknown source, V1.xx)
+    # conventional
     (b"{", 'edf'),
     (b"\r{", 'edf'),
     (b"\n{", 'edf'),
@@ -95,6 +102,7 @@ MAGIC_NUMBERS = [
     (b"\xFF\xD8\xFF\xE1", "jpeg"),
     # JPEG 2000 (from RFC 3745)
     (b"\x00\x00\x00\x0C\x6A\x50\x20\x20\x0D\x0A\x87\x0A", "jpeg2k"),
+    (b"ESPERANTO FORMAT", "esperanto"),
 ]
 
 
@@ -140,10 +148,10 @@ def openimage(filename, frame=None):
 
     if isinstance(filename, FilenameObject):
         try:
-            logger.debug("Attempting to open %s" % (filename.tostring()))
-            obj = _openimage(filename.tostring())
-            logger.debug("Attempting to read frame %s from %s with reader %s" % (frame, filename.tostring(), obj.classname))
-            obj = obj.read(filename.tostring(), frame)
+            logger.debug("Attempting to open %s" % (filename.tobytes()))
+            obj = _openimage(filename.tobytes())
+            logger.debug("Attempting to read frame %s from %s with reader %s" % (frame, filename.tobytes(), obj.classname))
+            obj = obj.read(filename.tobytes(), frame)
         except Exception as ex:
             # multiframe file
             # logger.debug( "DEBUG: multiframe file, start # %d"%(
