@@ -61,7 +61,7 @@ class TestFlatEdfs(unittest.TestCase):
         self.MYIMAGE[0, 0] = 0
         self.MYIMAGE[1, 1] = 20
 
-        assert len(self.MYIMAGE[0:1, 0:1].tostring()) == 4, self.MYIMAGE[0:1, 0:1].tostring()
+        assert len(self.MYIMAGE[0:1, 0:1].tobytes()) == 4, self.MYIMAGE[0:1, 0:1].tobytes()
 
     def setUp(self):
         """ initialize"""
@@ -71,7 +71,7 @@ class TestFlatEdfs(unittest.TestCase):
             outf = open(self.filename, "wb")
             assert len(self.MYHEADER) % 1024 == 0
             outf.write(self.MYHEADER)
-            outf.write(self.MYIMAGE.tostring())
+            outf.write(self.MYIMAGE.tobytes())
             outf.close()
 
         obj = edfimage()
@@ -419,7 +419,7 @@ class TestBadFiles(unittest.TestCase):
         data = numpy.ones((256, 256), numpy.float32) * 10
         data[0, 0] = 0
         data[1, 1] = 20
-        fd.write(data.tostring())
+        fd.write(data.tobytes())
 
     @classmethod
     def copy_base(cls, filename, size):
@@ -556,6 +556,39 @@ class TestBadGzFiles(TestBadFiles):
             TestBadFiles.write_data(gzfd)
 
 
+class TestSphere2SaxsSamples(unittest.TestCase):
+    """Test some samples from sphere2saxs"""
+
+    def setUp(self):
+        unittest.TestCase.setUp(self)
+        self.samples = UtilsTest.resources.getdir("sphere2saxs_output.tar.bz2")
+
+    SAMPLES = {
+        "multi.edf": (5, (200, 100), numpy.float32, (6.292408e-05, 0.5594252, 3.2911296, 0.82902604)),
+        "multi.edf.gz": (5, (200, 100), numpy.float32, (6.292408e-05, 0.5594252, 3.2911296, 0.82902604)),
+        "sphere.edf": (1, (200, 100), numpy.float32, (6.292408e-05, 0.5594252, 3.2911296, 0.82902604)),
+        "sphere.edf.gz": (1, (200, 100), numpy.float32, (6.292408e-05, 0.5594252, 3.2911296, 0.82902604)),
+    }
+
+    def test_all_images(self):
+        for filename in self.samples:
+            if not os.path.isfile(filename):
+                continue
+            with fabio.open(filename) as f:
+                logger.debug("Reading file %s", filename)
+                expected_data = self.SAMPLES[os.path.basename(filename)]
+                nframes, shape, dtype, datainfo = expected_data
+                self.assertEqual(f.nframes, nframes)
+                self.assertEqual(f.shape, shape)
+                self.assertEqual(f.dtype, dtype)
+                vmin, vmean, vmax, vstd = datainfo
+                self.assertEqual(f.dtype, dtype)
+                self.assertAlmostEqual(f.data.min(), vmin, places=4)
+                self.assertAlmostEqual(f.data.mean(), vmean, places=4)
+                self.assertAlmostEqual(f.data.max(), vmax, places=4)
+                self.assertAlmostEqual(f.data.std(), vstd, places=4)
+
+
 class TestEdfIterator(unittest.TestCase):
     """Read different EDF files with lazy iterator
     """
@@ -605,6 +638,7 @@ def suite():
     testsuite.addTest(loadTests(TestBadFiles))
     testsuite.addTest(loadTests(TestBadGzFiles))
     testsuite.addTest(loadTests(TestEdfIterator))
+    testsuite.addTest(loadTests(TestSphere2SaxsSamples))
     return testsuite
 
 
